@@ -22,6 +22,6 @@ int CalendarApplet::weekNumber(const QDateTime &dateTime) const
     return dateTime.date().weekNumber();
 }
 
-K_PLUGIN_CLASS_WITH_JSON(CalendarApplet, "package/metadata.json")
+K_PLUGIN_CLASS(CalendarApplet)
 
 #include "calendarapplet.moc"
