@@ -8,7 +8,6 @@
 
 #include <QAction>
 #include <QApplication>
-#include <QDesktopWidget>
 #include <QDir>
 #include <QDropEvent>
 #include <QFileInfo>
@@ -468,7 +467,6 @@ void IconApplet::processDrop(QObject *dropEvent)
                       static_cast<Qt::KeyboardModifiers>(dropEvent->property("modifiers").toInt()));
 
         KIO::DropJob *dropJob = KIO::drop(&de, m_url);
-        KJobWidgets::setWindow(dropJob, QApplication::desktop());
         return;
     }
 }
@@ -575,6 +573,6 @@ void IconApplet::setLocalPath(const QString &localPath)
     config().writeEntry(QStringLiteral("localPath"), localPath);
 }
 
-K_PLUGIN_CLASS_WITH_JSON(IconApplet, "package/metadata.json")
+K_PLUGIN_CLASS(IconApplet)
 
 #include "iconapplet.moc"
