@@ -6,6 +6,7 @@
 
 #include "appletslayout.h"
 #include "appletcontainer.h"
+#include "containmentlayoutmanager_debug.h"
 #include "gridlayoutmanager.h"
 
 #include <QQmlContext>
@@ -17,6 +18,9 @@
 #include <Containment>
 #include <Corona>
 #include <PlasmaQuick/AppletQuickItem>
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 AppletsLayout::AppletsLayout(QQuickItem *parent)
     : QQuickItem(parent)
@@ -28,7 +32,7 @@ AppletsLayout::AppletsLayout(QQuickItem *parent)
 
     m_saveLayoutTimer = new QTimer(this);
     m_saveLayoutTimer->setSingleShot(true);
-    m_saveLayoutTimer->setInterval(100);
+    m_saveLayoutTimer->setInterval(100ms);
     connect(m_layoutManager, &AbstractLayoutManager::layoutNeedsSaving, m_saveLayoutTimer, QOverload<>::of(&QTimer::start));
     connect(m_saveLayoutTimer, &QTimer::timeout, this, [this]() {
         // We can't assume m_containment to be valid: if we load in a plasmoid that can run also
@@ -52,14 +56,13 @@ AppletsLayout::AppletsLayout(QQuickItem *parent)
 
     m_layoutChangeTimer = new QTimer(this);
     m_layoutChangeTimer->setSingleShot(true);
-    m_layoutChangeTimer->setInterval(100);
+    m_layoutChangeTimer->setInterval(100ms);
     connect(m_layoutChangeTimer, &QTimer::timeout, this, [this]() {
         // We can't assume m_containment to be valid: if we load in a plasmoid that can run also
         // in "applet" mode, m_containment will never be valid
-        if (!m_containment || width() <= 0 || height() <= 0 || m_relayoutLock) {
+        if (!m_containment) {
             return;
         }
-
         const QString &serializedConfig = m_containment->config().readEntry(m_configKey, "");
         if ((m_layoutChanges & ConfigKeyChange) && !serializedConfig.isEmpty()) {
             if (!m_configKey.isEmpty() && m_containment) {
@@ -108,7 +111,7 @@ void AppletsLayout::setContainment(PlasmaQuick::AppletQuickItem *containmentItem
 {
     // Forbid changing containmentItem at runtime
     if (m_containmentItem || containmentItem == m_containmentItem || !containmentItem->applet() || !containmentItem->applet()->isContainment()) {
-        qWarning() << "Error: cannot change the containment to AppletsLayout";
+        qCWarning(CONTAINMENTLAYOUTMANAGER_DEBUG) << "Error: cannot change the containment to AppletsLayout";
         return;
     }
 
@@ -170,27 +173,6 @@ void AppletsLayout::setFallbackConfigKey(const QString &key)
     Q_EMIT fallbackConfigKeyChanged();
 }
 
-bool AppletsLayout::relayoutLock() const
-{
-    return m_relayoutLock;
-}
-
-void AppletsLayout::setRelayoutLock(bool lock)
-{
-    if (lock == m_relayoutLock) {
-        return;
-    }
-
-    m_relayoutLock = lock;
-
-    if (!lock && m_layoutChanges != NoChange) {
-        m_layoutChangeTimer->start();
-    }
-
-    Q_EMIT relayoutLockChanged();
-}
-
-
 QJSValue AppletsLayout::acceptsAppletCallback() const
 {
     return m_acceptsAppletCallback;
@@ -475,27 +457,43 @@ void AppletsLayout::releaseSpace(ItemContainer *item)
     m_layoutManager->releaseSpace(item);
 }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
 void AppletsLayout::geometryChanged(const QRectF &newGeometry, const QRectF &oldGeometry)
+#else
+void AppletsLayout::geometryChange(const QRectF &newGeometry, const QRectF &oldGeometry)
+#endif
 {
     // Ignore completely moves without resize
     if (newGeometry.size() == oldGeometry.size()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QQuickItem::geometryChanged(newGeometry, oldGeometry);
+#else
+        QQuickItem::geometryChange(newGeometry, oldGeometry);
+#endif
         return;
     }
 
     // Don't care for anything happening before startup completion
     if (!m_containment || !m_containment->corona() || !m_containment->corona()->isStartupCompleted()) {
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
         QQuickItem::geometryChanged(newGeometry, oldGeometry);
+#else
+        QQuickItem::geometryChange(newGeometry, oldGeometry);
+#endif
         return;
     }
 
     // Only do a layouting procedure if we received a valid size
-    if (!newGeometry.isEmpty() && newGeometry != oldGeometry) {
+    if (!newGeometry.isEmpty()) {
         m_layoutChanges |= SizeChange;
         m_layoutChangeTimer->start();
     }
 
+#if QT_VERSION < QT_VERSION_CHECK(6, 0, 0)
     QQuickItem::geometryChanged(newGeometry, oldGeometry);
+#else
+    QQuickItem::geometryChange(newGeometry, oldGeometry);
+#endif
 }
 
 void AppletsLayout::updatePolish()
@@ -720,7 +718,7 @@ AppletContainer *AppletsLayout::createContainerForApplet(PlasmaQuick::AppletQuic
         if (container) {
             container->setParentItem(this);
         } else {
-            qWarning() << "Error: provided component not an AppletContainer instance";
+            qCWarning(CONTAINMENTLAYOUTMANAGER_DEBUG) << "Error: provided component not an AppletContainer instance";
             if (instance) {
                 instance->deleteLater();
             }
