@@ -23,7 +23,7 @@
 #include <KIconLoader>
 #include <KJobWidgets>
 #include <KMessageBox>
-#include <KNewStuff3/KNS3/QtQuickDialogWrapper>
+#include <KNS3/QtQuickDialogWrapper>
 #include <KPluginFactory>
 #include <KStandardAction>
 #include <KToolBar>
@@ -249,7 +249,7 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList &)
     m_scanDuplicateFontsControl = new CPushButton(KGuiItem(i18n("Find Duplicates…"), "edit-duplicate", i18n("Scan for Duplicate Fonts…")), fontControlWidget);
 
     m_addFontControl = new CPushButton(KGuiItem(i18n("Install from File…"), "document-import", i18n("Install fonts from a local file")), fontControlWidget);
-    m_getNewFontsControl = new KNS3::Button(i18n("Get New Fonts…"), QStringLiteral("kfontinst.knsrc"), this);
+    m_getNewFontsControl = new KNSWidgets::Button(i18n("Get New Fonts…"), QStringLiteral("kfontinst.knsrc"), this);
     m_getNewFontsControl->setToolTip(i18n("Download new fonts"));
 
     m_deleteFontControl = new CPushButton(KGuiItem(QString(), "edit-delete", i18n("Delete Selected Fonts…")), fontControlWidget);
@@ -347,7 +347,7 @@ CKCmFontInst::CKCmFontInst(QWidget *parent, const QVariantList &)
     connect(m_enableGroupControl, &QAbstractButton::clicked, this, &CKCmFontInst::enableGroup);
     connect(m_disableGroupControl, &QAbstractButton::clicked, this, &CKCmFontInst::disableGroup);
     connect(m_addFontControl, SIGNAL(clicked()), SLOT(addFonts()));
-    connect(m_getNewFontsControl, &KNS3::Button::dialogFinished, this, &CKCmFontInst::downloadFonts);
+    connect(m_getNewFontsControl, &KNSWidgets::Button::dialogFinished, this, &CKCmFontInst::downloadFonts);
     connect(m_deleteFontControl, &QAbstractButton::clicked, this, &CKCmFontInst::deleteFonts);
     connect(m_scanDuplicateFontsControl, &QAbstractButton::clicked, this, &CKCmFontInst::duplicateFonts);
     // connect(validateFontsAct, SIGNAL(triggered(bool)), SLOT(validateFonts()));
@@ -387,8 +387,8 @@ QString CKCmFontInst::quickHelp() const
                             " font, simply copy it into the appropriate folder - "
                             " \"%1\" for fonts available to just yourself, or "
                             " \"%2\" for system-wide fonts (available to all).</p>",
-                            i18n(KFI_KIO_FONTS_USER),
-                            i18n(KFI_KIO_FONTS_SYS));
+                            KFI_KIO_FONTS_USER.toString(),
+                            KFI_KIO_FONTS_SYS.toString());
 }
 
 void CKCmFontInst::previewMenu(const QPoint &pos)
@@ -664,8 +664,8 @@ void CKCmFontInst::moveFonts()
                                                       i18n("<p>Do you really want to "
                                                            "move</p><p>\'<b>%1</b>\'</p><p>from <i>%2</i> to <i>%3</i>?</p>",
                                                            fontNames.first(),
-                                                           m_groupListView->isSystem() ? i18n(KFI_KIO_FONTS_SYS) : i18n(KFI_KIO_FONTS_USER),
-                                                           m_groupListView->isSystem() ? i18n(KFI_KIO_FONTS_USER) : i18n(KFI_KIO_FONTS_SYS)),
+                                                           m_groupListView->isSystem() ? KFI_KIO_FONTS_SYS.toString() : KFI_KIO_FONTS_USER.toString(),
+                                                           m_groupListView->isSystem() ? KFI_KIO_FONTS_USER.toString() : KFI_KIO_FONTS_SYS.toString()),
                                                       i18n("Move Font"),
                                                       KGuiItem(i18n("Move")));
             break;
@@ -675,8 +675,8 @@ void CKCmFontInst::moveFonts()
                                                           i18np("<p>Do you really want to move this font from <i>%2</i> to <i>%3</i>?</p>",
                                                                 "<p>Do you really want to move these %1 fonts from <i>%2</i> to <i>%3</i>?</p>",
                                                                 fontNames.count(),
-                                                                m_groupListView->isSystem() ? i18n(KFI_KIO_FONTS_SYS) : i18n(KFI_KIO_FONTS_USER),
-                                                                m_groupListView->isSystem() ? i18n(KFI_KIO_FONTS_USER) : i18n(KFI_KIO_FONTS_SYS)),
+                                                                m_groupListView->isSystem() ? KFI_KIO_FONTS_SYS.toString() : KFI_KIO_FONTS_USER.toString(),
+                                                                m_groupListView->isSystem() ? KFI_KIO_FONTS_USER.toString() : KFI_KIO_FONTS_SYS.toString()),
                                                           fontNames,
                                                           i18n("Move Fonts"),
                                                           KGuiItem(i18n("Move")));
@@ -793,7 +793,7 @@ void CKCmFontInst::duplicateFonts()
 //{
 //}
 
-void CKCmFontInst::downloadFonts(const QList<KNS3::Entry> &changedEntries)
+void CKCmFontInst::downloadFonts(const QList<KNSCore::Entry> &changedEntries)
 {
     if (changedEntries.isEmpty()) {
         return;
@@ -957,8 +957,8 @@ void CKCmFontInst::addFonts(const QSet<QUrl> &src)
                                                               "(only available to you), or "
                                                               "system-wide (available to all users)?"),
                                                          i18n("Where to Install"),
-                                                         KGuiItem(i18n(KFI_KIO_FONTS_USER)),
-                                                         KGuiItem(i18n(KFI_KIO_FONTS_SYS)))) {
+                                                         KGuiItem(KFI_KIO_FONTS_USER.toString()),
+                                                         KGuiItem(KFI_KIO_FONTS_SYS.toString()))) {
                 case KMessageBox::Yes:
                     system = false;
                     break;
