@@ -26,14 +26,21 @@
 #include <QSet>
 #include <QTimer>
 #include <QUrlQuery>
+#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+#include <private/qtx11extras_p.h>
+#else
 #include <QX11Info>
+#endif
+#include <chrono>
+
+using namespace std::chrono_literals;
 
 namespace TaskManager
 {
 static const NET::Properties windowInfoFlags =
     NET::WMState | NET::XAWMState | NET::WMDesktop | NET::WMVisibleName | NET::WMGeometry | NET::WMFrameExtents | NET::WMWindowType | NET::WMPid;
-static const NET::Properties2 windowInfoFlags2 =
-    NET::WM2DesktopFileName | NET::WM2Activities | NET::WM2WindowClass | NET::WM2AllowedActions | NET::WM2AppMenuObjectPath | NET::WM2AppMenuServiceName;
+static const NET::Properties2 windowInfoFlags2 = NET::WM2DesktopFileName | NET::WM2Activities | NET::WM2WindowClass | NET::WM2AllowedActions
+    | NET::WM2AppMenuObjectPath | NET::WM2AppMenuServiceName | NET::WM2GTKApplicationId;
 
 class Q_DECL_HIDDEN XWindowTasksModel::Private
 {
@@ -118,7 +125,7 @@ void XWindowTasksModel::Private::init()
     cachedStackingOrder = KWindowSystem::stackingOrder();
 
     sycocaChangeTimer.setSingleShot(true);
-    sycocaChangeTimer.setInterval(100);
+    sycocaChangeTimer.setInterval(100ms);
 
     QObject::connect(&sycocaChangeTimer, &QTimer::timeout, q, clearCacheAndRefresh);
 
@@ -204,7 +211,7 @@ void XWindowTasksModel::Private::addWindow(WId window)
     KWindowInfo info(window, NET::WMWindowType | NET::WMState | NET::WMName | NET::WMVisibleName, NET::WM2TransientFor);
 
     NET::WindowType wType = info.windowType(NET::NormalMask | NET::DesktopMask | NET::DockMask | NET::ToolbarMask | NET::MenuMask | NET::DialogMask
-                                            | NET::OverrideMask | NET::TopMenuMask | NET::UtilityMask | NET::SplashMask);
+                                            | NET::OverrideMask | NET::TopMenuMask | NET::UtilityMask | NET::SplashMask | NET::NotificationMask);
 
     const WId leader = info.transientFor();
 
@@ -494,6 +501,10 @@ QUrl XWindowTasksModel::Private::windowUrl(WId window)
 
     QString desktopFile = QString::fromUtf8(info->desktopFileName());
 
+    if (desktopFile.isEmpty()) {
+        desktopFile = QString::fromUtf8(info->gtkApplicationId());
+    }
+
     if (!desktopFile.isEmpty()) {
         KService::Ptr service = KService::serviceByStorageId(desktopFile);
 
