@@ -11,7 +11,6 @@
 
 #include <KDBusService>
 #include <KLocalizedString>
-#include <KQuickAddons/QtQuickSettings>
 
 #include "plasmawindowedcorona.h"
 #include "plasmawindowedview.h"
@@ -28,8 +27,6 @@ int main(int argc, char **argv)
 
     KDBusService service(KDBusService::Unique);
 
-    KQuickAddons::QtQuickSettings::init();
-
     QCommandLineParser parser;
     parser.setApplicationDescription(i18n("Plasma Windowed"));
     parser.addOption(
